@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -39,7 +39,7 @@ create(Context_t *ctx)
   int error;
   pa_sample_spec ss;
 
-  memset(pa_buff, 0, BUFF_SIZE);
+  memset(pa_buff, 0, BUFF_SIZE * sizeof(float));
 
   ss.format = PA_SAMPLE_FLOAT32LE;
   ss.channels = 2;
