@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -40,7 +40,7 @@ extern int webcams;
 
 
 void
-create(__attribute__ ((unused)) Context_t *ctx)
+create(Context_t *ctx)
 {
   if (!webcams)
     options |= BEQ_DISABLED;
@@ -50,7 +50,7 @@ create(__attribute__ ((unused)) Context_t *ctx)
 
 
 void
-delete(__attribute__ ((unused)) Context_t *ctx)
+delete(Context_t *ctx)
 {
   Buffer8_delete(diff);
 }
