@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -55,7 +55,7 @@ static Shuffler_t *shuffler = NULL;
 
 
 void
-create(__attribute__ ((unused)) Context_t *ctx)
+create(Context_t *ctx)
 {
   cirrus_alarm = Alarm_new(3, 10);
   shuffler = Shuffler_new(NCOLORS);
@@ -63,7 +63,7 @@ create(__attribute__ ((unused)) Context_t *ctx)
 
 
 void
-destroy(__attribute__ ((unused)) Context_t *ctx)
+destroy(Context_t *ctx)
 {
   Alarm_delete(cirrus_alarm);
   Shuffler_delete(shuffler);
@@ -89,7 +89,7 @@ random_color()
 
 
 void
-on_switch_on(__attribute__ ((unused)) Context_t *ctx)
+on_switch_on(Context_t *ctx)
 {
   src_color_idx = Shuffler_get(shuffler);
   random_color();
