@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -105,7 +105,7 @@ randomize_all()
 
 
 void
-on_switch_on(__attribute__ ((unused)) Context_t *ctx)
+on_switch_on(Context_t *ctx)
 {
   randomize_all();
 }
@@ -130,7 +130,7 @@ create(Context_t *ctx)
 
 
 void
-destroy(__attribute__ ((unused)) Context_t *ctx)
+destroy(Context_t *ctx)
 {
   if (critters != NULL)
     xfree(critters);
