@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -129,7 +129,7 @@ create(Context_t *ctx)
 
 
 void
-destroy(__attribute__ ((unused)) Context_t *ctx)
+destroy(Context_t *ctx)
 {
   if (ps != NULL)
     Particle_System_delete(ps);
