@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -33,7 +33,7 @@ static const Picture8_t *pic = NULL;
 
 
 void
-create(__attribute__ ((unused)) Context_t *ctx)
+create(Context_t *ctx)
 {
   if (pictures == NULL)
     options |= BEQ_DISABLED;
@@ -41,7 +41,7 @@ create(__attribute__ ((unused)) Context_t *ctx)
 
 
 void
-on_switch_on(__attribute__ ((unused)) Context_t *ctx)
+on_switch_on(Context_t *ctx)
 {
   pic = Pictures_random(pictures);
 }
