@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -156,7 +156,7 @@ static VectorField_t *vf = NULL;
 
 
 void
-create(__attribute__ ((unused)) Context_t *ctx)
+create(Context_t *ctx)
 {
   vf = VectorField_new(NB_FCT, &fct);
   timer = b_timer_new();
@@ -165,7 +165,7 @@ create(__attribute__ ((unused)) Context_t *ctx)
 
 
 void
-destroy(__attribute__ ((unused)) Context_t *ctx)
+destroy(Context_t *ctx)
 {
   VectorField_delete(vf);
   b_timer_delete(timer);
@@ -174,7 +174,7 @@ destroy(__attribute__ ((unused)) Context_t *ctx)
 
 
 void
-on_switch_on(__attribute__ ((unused)) Context_t *ctx)
+on_switch_on(Context_t *ctx)
 {
   num_effect = Shuffler_get(shuffler);
   b_timer_start(timer);
