@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -34,7 +34,7 @@ static short size = 0;
 
 
 void
-on_switch_on(__attribute__ ((unused)) Context_t *ctx)
+on_switch_on(Context_t *ctx)
 {
   mode = EXPAND;
   size = 2;
@@ -42,26 +42,16 @@ on_switch_on(__attribute__ ((unused)) Context_t *ctx)
 
 
 static int
-pgcd(int a, int b)
+gcd(int a, int b)
 {
-  while (a * b) {
-    if (a > b)
-      a -= b;
-    else
-      b -= a;
-
-    if (!a || !b)
-      break;
-  }
-
-  return ((a) ? a : b);
+  return b ? gcd(b, a % b) : a;
 }
 
 
 static int
-ok(__attribute__ ((unused)) Context_t *ctx)
+ok(Context_t *ctx)
 {
-  int p = pgcd(WIDTH, HEIGHT);
+  int p = gcd(WIDTH, HEIGHT);
 
   /* blah blah checker des trucs ici */
   max_size = ((WIDTH % p) || (HEIGHT % p)) ? p * 2 : p;
