@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -225,7 +225,7 @@ post_init()
 
 
 void
-create(__attribute__ ((unused)) Context_t *ctx)
+create(Context_t *ctx)
 {
   ci = cexp(I*M_PI/2);
   /* printf("Rotors:  %f+%f*i\n", creal(ci), cimag(ci)); */
@@ -355,7 +355,7 @@ u_char on_SDL_Event (Context_t *ctx, const SDL_Event *e) {
 #endif
 
 void
-on_switch_on(__attribute__ ((unused)) Context_t *ctx)
+on_switch_on(Context_t *ctx)
 {
   post_init();
 }
