@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -117,7 +117,7 @@ create(Context_t *ctx)
 
 
 void
-destroy(__attribute__ ((unused)) Context_t *ctx)
+destroy(Context_t *ctx)
 {
   if (P != NULL)
     Porteuse_delete(P);
@@ -125,7 +125,7 @@ destroy(__attribute__ ((unused)) Context_t *ctx)
 
 
 void
-on_switch_on(__attribute__ ((unused)) Context_t *ctx)
+on_switch_on(Context_t *ctx)
 {
   /* connect = b_rand_boolean(); */
 }
