@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -38,7 +38,7 @@ static BTimer_t *splash_timer = NULL;
 
 
 void
-on_switch_on(__attribute__ ((unused)) Context_t *ctx)
+on_switch_on(Context_t *ctx)
 {
   u_long i;
 
@@ -58,7 +58,7 @@ on_switch_on(__attribute__ ((unused)) Context_t *ctx)
 
 
 void
-create(__attribute__ ((unused)) Context_t *ctx)
+create(Context_t *ctx)
 {
   if (pictures == NULL)
     options |= BEQ_DISABLED;
@@ -72,7 +72,7 @@ create(__attribute__ ((unused)) Context_t *ctx)
 
 
 void
-destroy(__attribute__ ((unused)) Context_t *ctx)
+destroy(Context_t *ctx)
 {
   if (pictures != NULL) {
     xfree(splash_map);
