@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -161,7 +161,7 @@ prepare(Shuffler_t *shf)
 
 
 void
-create(__attribute__ ((unused)) Context_t *ctx)
+create(Context_t *ctx)
 {
   if ((WIDTH<3*MIN_SIZE) || (HEIGHT<3*MIN_SIZE)) {
     printf("[!] taquin: not enough space\n");
@@ -178,7 +178,7 @@ create(__attribute__ ((unused)) Context_t *ctx)
 
 
 void
-destroy(__attribute__ ((unused)) Context_t *ctx)
+destroy(Context_t *ctx)
 {
   if (NULL != map)
     xfree(map);
@@ -316,7 +316,7 @@ run(Context_t *ctx)
 
 
 void
-on_switch_on(__attribute__ ((unused)) Context_t *ctx)
+on_switch_on(Context_t *ctx)
 {
   u_long k;
 	
