@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -29,7 +29,7 @@ static u_long *tunnel;
 
 
 void
-create(__attribute__ ((unused)) Context_t *ctx)
+create(Context_t *ctx)
 { 
 	u_short di, dj, start;
 	float length;
@@ -57,7 +57,7 @@ create(__attribute__ ((unused)) Context_t *ctx)
 
 
 void
-destroy(__attribute__ ((unused)) Context_t *ctx)
+destroy(Context_t *ctx)
 {
   xfree(tunnel);
 }
