@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -34,7 +34,7 @@ static Buffer8_t *game[2] = { NULL, NULL };
 
 
 void
-create(__attribute__ ((unused)) Context_t *ctx)
+create(Context_t *ctx)
 {
   game[0] = Buffer8_new();
   game[1] = Buffer8_new();
@@ -42,7 +42,7 @@ create(__attribute__ ((unused)) Context_t *ctx)
 
 
 void
-destroy(__attribute__ ((unused)) Context_t *ctx)
+destroy(Context_t *ctx)
 {
   assert(game[0] != NULL);
   Buffer8_delete(game[0]);
@@ -52,7 +52,7 @@ destroy(__attribute__ ((unused)) Context_t *ctx)
 
 
 void
-on_switch_on(__attribute__ ((unused)) Context_t *ctx)
+on_switch_on(Context_t *ctx)
 {
   Buffer8_randomize(game[0]);
 }
