@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -86,7 +86,7 @@ initDistTable()
 
 
 static void
-initWarp(__attribute__ ((unused)) Context_t *ctx)
+initWarp(Context_t *ctx)
 {
   Warp.offstable = xcalloc(HEIGHT, sizeof(char *));
   Warp.disttable = xcalloc(BUFFSIZE, sizeof(short));
@@ -163,7 +163,7 @@ create(Context_t *ctx)
 
 
 void
-destroy(__attribute__ ((unused)) Context_t *ctx)
+destroy(Context_t *ctx)
 {
   disposeWarp();
 }
