@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -41,7 +41,7 @@ static yscanline_conf yscanline_cf;
 
 
 void
-create(__attribute__ ((unused)) Context_t *ctx)
+create(Context_t *ctx)
 {
   if (pictures == NULL)
     options |= BEQ_DISABLED;
@@ -54,7 +54,7 @@ create(__attribute__ ((unused)) Context_t *ctx)
 
 
 void
-on_switch_on(__attribute__ ((unused)) Context_t *ctx)
+on_switch_on(Context_t *ctx)
 {
   yscanline_cf.dir = (b_rand_boolean()) ? -1 : 1;
   yscanline_cf.ping_pong = b_rand_boolean();
