@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -199,7 +199,7 @@ tex_point(const float x, const float y)
 
 
 void
-test_gl3(__attribute__ ((unused)) Context_t *ctx)
+test_gl3(Context_t *ctx)
 {
   Context_make_GL_RGBA_texture(ctx, ACTIVE_BUFFER);
 
@@ -274,7 +274,7 @@ fullscreen(const int fs)
 
 
 void
-destroy(__attribute__ ((unused)) Context_t *ctx)
+destroy(Context_t *ctx)
 {
 #ifndef FIXED
   /*
@@ -325,7 +325,7 @@ init_GL()
 
 
 void
-create(__attribute__ ((unused)) Context_t *ctx)
+create(Context_t *ctx)
 {
   char *window_title;
 
