@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -19,7 +19,7 @@
 
 #include "SDL.h"
 #include "ttf.h"
-#include "defaults.h"
+#include "src/defaults.h"
 
 #define NO_MOUSE_CURSOR
 
@@ -103,7 +103,7 @@ SDL_get_event(Context_t *ctx)
 
   SDL_Event evt;
 
-  while (SDL_PollEvent(&evt)) {
+  while (SDL_PollEvent(&evt) != 0) {
     BKey_t key;
 
     switch (evt.type) {
@@ -228,18 +228,23 @@ run(Context_t *ctx)
 
 
 void
-create(__attribute__ ((unused)) Context_t *ctx)
+create(Context_t *ctx)
 {
   char *window_title;
   char *icon_file;
   SDL_Surface *icon = NULL;
   Uint32 flags = 0;
   Uint32 colorkey;
+  Uint32 subsystems;
+  int ret;
 
   /* Initialize SDL */
-  if (!SDL_WasInit(SDL_INIT_VIDEO))
-    if (SDL_Init(SDL_INIT_VIDEO) < 0)
+  subsystems = SDL_WasInit(SDL_INIT_VIDEO);
+  if (subsystems == 0) {
+    ret = SDL_Init(SDL_INIT_VIDEO);
+    if (ret == -1)
       xerror("Couldn't initialize SDL: %s\n", SDL_GetError());
+  }
 
   ttf_init();
 
@@ -253,8 +258,7 @@ create(__attribute__ ((unused)) Context_t *ctx)
   SDL_FreeSurface(icon);
 
   flags = SDL_HWSURFACE | SDL_ANYFORMAT | SDL_HWPALETTE |
-    SDL_DOUBLEBUF | SDL_HWACCEL |
-    SDL_RLEACCEL;
+          SDL_DOUBLEBUF | SDL_HWACCEL | SDL_RLEACCEL;
 
 #ifndef FIXED
   flags |= SDL_RESIZABLE;
@@ -280,7 +284,7 @@ create(__attribute__ ((unused)) Context_t *ctx)
 
 
 void
-destroy(__attribute__ ((unused)) Context_t *ctx)
+destroy(Context_t *ctx)
 {
 #ifndef FIXED
   sws_freeContext(sws_context);
