@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -18,12 +18,9 @@
  */
 
 #include <libswscale/swscale.h>
-#include <libavutil/mem.h>
 #include "buffer_8bits.h"
 #include "brandom.h"
 
-/* TODO: Cleanup, remove XXDEBUG code when we are sure draw_line is ok */
-
 /*!
  * \brief Create a pixel buffer
  */
@@ -123,14 +120,7 @@ draw_line(Buffer8_t *buff, short x1, short y1, short x2, short y2, const Pixel_t
   short dx, dy, mod;
   char  sgn_dy;
 
-#ifdef XXDEBUG
-  printf("oOo draw_line: (%d, %d) -> (%d, %d)\n", x1, y1, x2, y2);
-#endif
-
   if ((x1 == x2) && (y1 == y2)) {
-#ifdef XXDEBUG
-    printf("(1) set_pixel_nc(%d, %d)\n", x1, y1);
-#endif
     set_pixel(buff, x1, y1, c);
     return;
   };
@@ -139,25 +129,12 @@ draw_line(Buffer8_t *buff, short x1, short y1, short x2, short y2, const Pixel_t
   q.x = x2; q.y = y2;
 
   if (!ks_clip_line (&exists, &p0, &q0, &p, &q)) {
-#ifdef XXDEBUG
-    printf ("inside\n");
-#endif
   } else if (exists) {
-#ifdef XXDEBUG
-    printf ("clipping (%d, %d) (%d, %d)\t=> ", x1, y1, x2, y2);
-#endif
-
     x1 = (short)q0.x;
     y1 = (short)q0.y;
     x2 = (short)p0.x;
     y2 = (short)p0.y;
-#ifdef XXDEBUG
-    printf ("clipped (%d, %d) (%d, %d)\n", x1, y1, x2, y2);
-#endif
   } else {
-#ifdef XXDEBUG
-    printf ("outside\n");
-#endif
     return;
   }
 	
@@ -188,14 +165,7 @@ draw_line(Buffer8_t *buff, short x1, short y1, short x2, short y2, const Pixel_t
       if (mod >/*=*/ 0)
 	y1 += sgn_dy, mod -= dx;
 
-#ifdef XXDEBUG
-      printf("(2) set_pixel_nc(%d, %d)... ", x1, y1);
-      fflush(stdout);
-#endif
       set_pixel_nc(buff, x1, y1, c);
-#ifdef XXDEBUG
-      printf("done\n");
-#endif
       
       if (x1 == x2)
 	return;
@@ -205,14 +175,7 @@ draw_line(Buffer8_t *buff, short x1, short y1, short x2, short y2, const Pixel_t
       if (mod >/*=*/ 0)
 	x1++, mod -= dy;
 			
-#ifdef XXDEBUG
-      printf("(3) set_pixel_nc(%d, %d)... ", x1, y1);
-      fflush(stdout);
-#endif
       set_pixel_nc(buff, x1, y1, c);
-#ifdef XXDEBUG
-      printf("done\n");
-#endif			
 
       if (y1 == y2)
 	return;
