@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -24,6 +24,9 @@
 #include "constants.h"
 #include "point2d.h"
 
+#define PIXEL_MINVAL       ((Pixel_t) (0))
+#define PIXEL_MAXVAL       ((Pixel_t) (~0))
+#define PIXEL_TRANSPARENT  (PIXEL_MINVAL)
 
 /**
  * \typedef Pixel_t
@@ -58,11 +61,7 @@ get_pixel_nc(const Buffer8_t *buf, const short x, const short y)
   /*  if ((x < MINX) || (y < MINY) || (x > MAXX) || (y > MAXY)) { */
   if (!((unsigned)(x-MINX) < (WIDTH-MINX)) || !((unsigned)(y-MINY) < (HEIGHT-MINY))) {
     printf("[!] want to get_pixel_nc(%d, %d)\n", x, y);
-#ifdef XDEBUG
-    exit(1);
-#else
     return 0;
-#endif /* XDEBUG */
   }
 #endif /* DEBUG */
 #endif /* !UNSAFE */
@@ -79,11 +78,7 @@ set_pixel_nc(Buffer8_t *buf, const short x, const short y, const Pixel_t col)
   /* if ((x < MINX) || (y < MINY) || (x > MAXX) || (y > MAXY)) { */
   if (!((unsigned)(x-MINX) < (WIDTH-MINX)) || !((unsigned)(y-MINY) < (HEIGHT-MINY))) {
     printf("[!] want to set_pixel_nc(%d, %d, %d)\n", x, y, col);
-#ifdef XDEBUG
-    exit(1);
-#else
     return;
-#endif /* XDEBUG */
   }
 #endif /* DEBUG */
 #endif /* !UNSAFE */
@@ -100,11 +95,7 @@ neg_pixel_nc(Buffer8_t *buf, const short x, const short y)
   /* if ((x < MINX) || (y < MINY) || (x > MAXX) || (y > MAXY)) { */
   if (!((unsigned)(x-MINX) < (WIDTH-MINX)) || !((unsigned)(y-MINY) < (HEIGHT-MINY))) {
     printf("[!] want to neg_pixel_nc(%d, %d)\n", x, y);
-#ifdef XDEBUG
-    exit(1);
-#else
     return;
-#endif /* XDEBUG */
   }
 #endif /* DEBUG */
 #endif /* !UNSAFE */ 
