@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -196,5 +196,7 @@ CmapFader_random(CmapFader_t *cf)
 int
 CmapFader_ring(const CmapFader_t *cf)
 {
-  return (cf->fader->fading && (b_timer_elapsed(cf->fader->timer)*MFACTOR));
+  const Fader_t *fader = cf->fader;
+
+  return (fader->fading && ((b_timer_elapsed(fader->timer) * MFACTOR) > 0));
 }
