@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -175,7 +175,7 @@ Context_new()
     gchar *tmp;
     int res;
 
-    tmp = g_strdup_printf("%s/%s", data_dir, "/images/zebulon/z-biniou-tv-1.png");
+    tmp = g_strdup_printf("%s/%s", data_dir, "images/zebulon/z-biniou-tv-1.png");
     VERBOSE(printf("[+] Loading '%s'\n", tmp));
     res = Picture8_load_PNG(ctx->target_pic, tmp);
     assert(!res);
@@ -186,7 +186,7 @@ Context_new()
 #endif
 
 #ifdef WITH_WEBCAM
-  VERBOSE(printf("[i] Initialazing %d webcams base: %s\n", webcams, video_base));
+  VERBOSE(printf("[i] Initializing %d webcams base: %s\n", webcams, video_base));
 
   ctx->cam = 0;
   Context_open_webcam(ctx);
