@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -59,7 +59,7 @@ typedef struct BKey_s {
 
 
 typedef struct Context_s {
-  char      running:1;
+  u_char    running:1;
 
   Plugin_t  *input_plugin;
   Input_t   *input;
@@ -77,7 +77,7 @@ typedef struct Context_s {
   Buffer8_t *cam_save[MAX_CAMS][CAM_SAVE];
   Buffer8_t *cam_ref[MAX_CAMS];
   BufferRGBA_t *rgba_cam_buffers[MAX_CAMS];
-  char ref_taken[MAX_CAMS];
+  u_char ref_taken[MAX_CAMS];
 #endif
 
   /* Faders */
@@ -105,17 +105,17 @@ typedef struct Context_s {
   BTimer_t *timer;
 
   /* FPS stuff */
-  char     sync_fps:1;
+  u_char   sync_fps:1;
   u_short  max_fps;
   float    i_max_fps; /* inverse of the maximum frames per second */
   int      fps[NFPS];
   BTimer_t  *fps_timer;
 
   enum OSDMode   osd_mode;
-  char     fullscreen:1;
-  char     display_colormap:1;
-  char     take_screenshot:1;
-  char     bypass:1;
+  u_char   fullscreen:1;
+  u_char   display_colormap:1;
+  u_char   take_screenshot:1;
+  u_char   bypass:1;
 
   void (*events_cb)(struct Context_s *, const BKey_t *); /* events callback */
 
@@ -133,18 +133,18 @@ typedef struct Context_s {
 
   /* OpenGL */
 #ifdef WITH_GL
-  char texture_ready:1;
-  char texture_used:1;
-  char gl_done:1;
+  u_char texture_ready:1;
+  u_char texture_used:1;
+  u_char gl_done:1;
   GLuint textures[NSCREENS];
   GLuint cam_textures[MAX_CAMS];
-  char pulse_3d:1;
-  char force_cube:1;
+  u_char pulse_3d:1;
+  u_char force_cube:1;
 #endif
 
   /* Target */
 #ifdef FEAT_TARGET
-  char       target:1;
+  u_char     target:1;
   Picture8_t *target_pic;
 #endif
 } Context_t;
