@@ -1,5 +1,5 @@
 /*
- *  Copyright 1994-2016 Olivier Girondel
+ *  Copyright 1994-2018 Olivier Girondel
  *
  *  This file is part of lebiniou.
  *
@@ -49,12 +49,12 @@ char *video_base = NULL;
   "\n"							\
   "           .:[ " PACKAGE_STRING " ]:.\n"             \
   " -------------------------------------------\n"	\
-  "  \"Une cause tres petite, qui nous echappe,\n"	\
-  "  determine un effet considerable que nous \n"	\
+  "  \"Une cause très petite, qui nous échappe,\n"	\
+  "  détermine un effet considérable que nous \n"	\
   "  ne pouvons pas ne pas voir, et alors nous\n"	\
-  "  disons que cet effet est du au hasard.\" \n"	\
+  "  disons que cet effet est dû au hasard.\" \n"	\
   "\n"				 			\
-  "    -- Henri Poincare, 1908\n"  	                \
+  "    -- Henri Poincaré, 1908\n"  	                \
   " -------------------------------------------\n"
 
 
@@ -129,11 +129,6 @@ main(int argc, char **argv)
   getargs(argc, argv);
   register_signals();
 
-  if (NULL == pid_file)
-    pid_file = "/tmp/lebiniou.pid";
-
-  write_pid_file();
-
   /* Banner */
   if (NULL == getenv("BINIOU_NO_BANNER"))
     do_banner();
@@ -150,6 +145,11 @@ main(int argc, char **argv)
 	     );
   xfree(themes);
 
+  if (NULL == pid_file)
+    pid_file = "/tmp/lebiniou.pid";
+
+  write_pid_file();
+
   biniou_set_max_fps(max_fps);
   biniou_set_random_mode(random_mode);
   biniou_set_osd_mode(osd_mode);
